@@ -18,23 +18,22 @@ from elementpath.xpath_nodes import AttributeNode, TextNode, TypedAttribute, \
     etree_deep_equal, match_element_node, match_attribute_node, is_comment_node, \
     is_document_node, is_processing_instruction_node, node_attributes, node_base_uri, \
     node_document_uri, node_children, node_nilled, node_kind, node_name, \
-    etree_iter_nodes, etree_iterpath
-from elementpath.schema_proxy import AbstractXsdType
+    etree_iter_nodes, etree_iter_paths
 
 
-class DummyXsdType(AbstractXsdType):
+class DummyXsdType:
     name = local_name = None
 
-    def is_matching(self, name, default_namespace): return False
-    def is_empty(self): return False
-    def is_simple(self): return False
-    def has_simple_content(self): return False
-    def has_mixed_content(self): return False
-    def is_element_only(self): return False
-    def is_key(self): return False
-    def is_qname(self): return False
-    def is_notation(self): return False
-    def decode(self, obj, *args, **kwargs): return None
+    def is_matching(self, name, default_namespace): pass
+    def is_empty(self): pass
+    def is_simple(self): pass
+    def has_simple_content(self): pass
+    def has_mixed_content(self): pass
+    def is_element_only(self): pass
+    def is_key(self): pass
+    def is_qname(self): pass
+    def is_notation(self): pass
+    def decode(self, obj, *args, **kwargs): pass
     def validate(self, obj, *args, **kwargs): pass
 
 
@@ -347,23 +346,23 @@ class XPathNodesTest(unittest.TestCase):
             typed_attr = TypedAttribute(attribute=attr, xsd_type=xsd_type, value=20)
             self.assertEqual(node_name(typed_attr), 'a1')
 
-    def test_etree_iterpath(self):
+    def test_etree_iter_paths(self):
         root = ElementTree.XML('<a><b1><c1/><c2/></b1><b2/><b3><c3/></b3></a>')
         root[2].append(ElementTree.Comment('a comment'))
         root[2].append(ElementTree.Element('c3'))  # duplicated tag
 
-        items = list(etree_iterpath(root))
+        items = list(etree_iter_paths(root))
         self.assertListEqual(items, [
             (root, '.'), (root[0], './b1'), (root[0][0], './b1/c1'),
             (root[0][1], './b1/c2'), (root[1], './b2'), (root[2], './b3'),
             (root[2][0], './b3/c3[1]'), (root[2][2], './b3/c3[2]')
         ])
-        self.assertListEqual(list(etree_iterpath(root, path='')), [
+        self.assertListEqual(list(etree_iter_paths(root, path='')), [
             (root, ''), (root[0], 'b1'), (root[0][0], 'b1/c1'),
             (root[0][1], 'b1/c2'), (root[1], 'b2'), (root[2], 'b3'),
             (root[2][0], 'b3/c3[1]'), (root[2][2], 'b3/c3[2]')
         ])
-        self.assertListEqual(list(etree_iterpath(root, path='/')), [
+        self.assertListEqual(list(etree_iter_paths(root, path='/')), [
             (root, '/'), (root[0], '/b1'), (root[0][0], '/b1/c1'),
             (root[0][1], '/b1/c2'), (root[1], '/b2'), (root[2], '/b3'),
             (root[2][0], '/b3/c3[1]'), (root[2][2], '/b3/c3[2]')
